summaryrefslogtreecommitdiff
path: root/source3/utils/profiles.c
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-03-23 18:14:17 +0100
committerMichael Adam <obnox@samba.org>2009-04-27 11:21:02 +0200
commit221151a2a2c30e5c82b100161b498fdbbc1d4382 (patch)
treed4346a16206b3308ff20b026012aa095e99d778a /source3/utils/profiles.c
parent38d02c5d857ecea3405c3f48e64906764329f1a1 (diff)
downloadsamba-221151a2a2c30e5c82b100161b498fdbbc1d4382.tar.gz
samba-221151a2a2c30e5c82b100161b498fdbbc1d4382.tar.bz2
samba-221151a2a2c30e5c82b100161b498fdbbc1d4382.zip
s3:registry: replace typedef REGVAL_CTR by struct regval_ctr.
This paves the way for hiding the typedef and the implementation from the surface. Michael
Diffstat (limited to 'source3/utils/profiles.c')
-rw-r--r--source3/utils/profiles.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source3/utils/profiles.c b/source3/utils/profiles.c
index 0ac93dedeb..0dc9aca876 100644
--- a/source3/utils/profiles.c
+++ b/source3/utils/profiles.c
@@ -117,7 +117,7 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
{
REGF_NK_REC *key, *subkey;
SEC_DESC *new_sd;
- REGVAL_CTR *values;
+ struct regval_ctr *values;
struct regsubkey_ctr *subkeys;
int i;
char *path;
@@ -139,13 +139,13 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
return False;
}
- if ( !(values = TALLOC_ZERO_P( subkeys, REGVAL_CTR )) ) {
+ if ( !(values = TALLOC_ZERO_P( subkeys, struct regval_ctr )) ) {
TALLOC_FREE( subkeys );
DEBUG(0,("copy_registry_tree: talloc() failure!\n"));
return False;
}
/* copy values into the REGVAL_CTR */
for ( i=0; i<nk->num_values; i++ ) {
regval_ctr_addvalue( values, nk->values[i].valuename, nk->values[i].type,
@@ -139,13 +139,13 @@ static bool copy_registry_tree( REGF_FILE *infile, REGF_NK_REC *nk,
return False;
}
- /* copy values into the REGVAL_CTR */
+ /* copy values into the struct regval_ctr */
for ( i=0; i<nk->num_values; i++ ) {
regval_ctr_addvalue( values, nk->values[i].valuename, nk->values[i].type,